window.Gleam.initSearch([{"doc":"sorbet","title":"sorbet","content":"# sorbet\n\n[![Package Version](https://img.shields.io/hexpm/v/sorbet)](https://hex.pm/packages/sorbet)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/sorbet/)\n\nA simple key-value configuration format parser and formatter for Gleam with support for multi-line values.\n\n## Installation\n\n```sh\ngleam add sorbet@1\n```\n\n## Usage\n\n### Parsing Sorbet Format\n\n```gleam\nimport sorbet\nimport gleam/io\n\npub fn main() {\n  // Simple key-value pairs\n  let config = &quot;name =&gt; Sorbet\\nversion =&gt; 1.0.0&quot;\n  let parsed = sorbet.parse(config)\n  \n  // Access values\n  io.debug(parsed) // Dict{&quot;name&quot;: &quot;Sorbet&quot;, &quot;version&quot;: &quot;1.0.0&quot;}\n  \n  // Multi-line values\n  let multi_line = &quot;description =&gt; A configuration format\\n&gt; with support for\\n&gt; multi-line values&quot;\n  let parsed_multi = sorbet.parse(multi_line)\n  \n  // The multi-line value is joined with newlines\n  io.debug(parsed_multi) // Dict{&quot;description&quot;: &quot;A configuration format\\nwith support for\\nmulti-line values&quot;}\n}\n```\n\n### Formatting to Sorbet Format\n\n```gleam\nimport sorbet\nimport gleam/dict\nimport gleam/io\n\npub fn main() {\n  // Format a single key-value pair\n  let formatted = sorbet.format_key_value(&quot;name&quot;, &quot;Sorbet&quot;)\n  io.println(formatted) // Prints: name =&gt; Sorbet\n  \n  // Format a multi-line value\n  let multi_line = sorbet.format_key_value(\n    &quot;description&quot;, \n    &quot;A configuration format\\nwith support for\\nmulti-line values&quot;\n  )\n  io.println(multi_line)\n  // Prints:\n  // description =&gt; A configuration format\n  // &gt; with support for\n  // &gt; multi-line values\n  \n  // Format a dictionary to Sorbet format\n  let config = dict.from_list([\n    #(&quot;name&quot;, &quot;Sorbet&quot;),\n    #(&quot;version&quot;, &quot;1.0.0&quot;),\n    #(&quot;description&quot;, &quot;A simple config format&quot;)\n  ])\n  \n  let formatted_dict = sorbet.format_dict(config)\n  io.println(formatted_dict)\n  // Prints something like:\n  // name =&gt; Sorbet\n  // version =&gt; 1.0.0\n  // description =&gt; A simple config format\n}\n```\n\n## Sorbet Format\n\nSorbet is a simple key-value configuration format with the following rules:\n- Each key-value pair is on a separate line with the format `key =&gt; value`\n- Multi-line values use continuation lines starting with `&gt;`\n- Empty lines are ignored\n- Whitespace around keys and values is trimmed\n\nExample:\n```\n# This is a Sorbet configuration file\nname =&gt; My Project\ndescription =&gt; This is a multi-line\n&gt; description for my project\n&gt; that spans multiple lines\nversion =&gt; 1.0.0\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/sorbet&gt;.\n\n## Development\n\n```sh\ngleam test  # Run the tests\n```\n","url":"index.html"},{"doc":"utility","title":"SorbetError","content":"pub type SorbetError {\n  Syntax\n  SyntaxException\n}\n Represents different types of errors that can occur during Sorbet parsing.\n\n ## Variants\n - `Syntax`: Represents basic syntax errors in the input format\n - `SyntaxException`: Represents more severe syntax exceptions, such as\n   continuation lines without a preceding key-value pair\n\nSyntax\n\n\nSyntaxException\n\n\nSynonyms:\nutility.SorbetError\nutility SorbetError","url":"utility.html#SorbetError"},{"doc":"utility","title":"print_error","content":"pub fn print_error(error: SorbetError, message: String) -&gt; Nil\n Prints a formatted error message to the console.\n\n Takes an error type and a message, formats them together with appropriate\n prefixes, and outputs the result to standard output.\n\n ## Parameters\n - `error`: The type of error that occurred\n - `message`: A descriptive message explaining the error\n\n ## Returns\n - `Nil`: This function performs a side effect and doesn&#39;t return a value\n\n ## Example\n\n \n print_error(Syntax, &quot;Invalid key-value format&quot;)\n // Prints: &quot;Syntax Error: Invalid key-value format&quot;\n \n\nSynonyms:\nutility.print_error\nutility print_error","url":"utility.html#print_error"},{"doc":"utility","title":"utility","content":" Utility\n This is the utility module for Sorbet.\n It contains error handling types and functions for the Sorbet parser.","url":"utility.html"},{"doc":"sorbet","title":"format_dict","content":"pub fn format_dict(map: Dict(String, String)) -&gt; String\n Format a dictionary into the sorbet format.\n\n Takes a dictionary of string keys and string values and converts it\n to a string in Sorbet format. Multi-line values are properly formatted\n with continuation lines.\n\n ## Example\n\n \n sorbet.format_dict(dict.from_list([\n   #(&quot;key1&quot;, &quot;value1&quot;),\n   #(&quot;key2&quot;, &quot;line1\\nline2&quot;)\n ]))\n // Returns &quot;key1 =&gt; value1\\nkey2 =&gt; line1\\n&gt; line2&quot;\n \n\nSynonyms:\nsorbet.format_dict\nsorbet format_dict","url":"sorbet.html#format_dict"},{"doc":"sorbet","title":"format_key_value","content":"pub fn format_key_value(key: String, value: String) -&gt; String\n Format a key and value into the sorbet format.\n If the value contains newlines, they will be formatted as continuation lines.\n\n ## Examples\n\n \n sorbet.format_key_value(&quot;key&quot;, &quot;value&quot;)\n // Returns &quot;key =&gt; value&quot;\n\n sorbet.format_key_value(&quot;key&quot;, &quot;line1\\nline2&quot;)\n // Returns &quot;key =&gt; line1\\n&gt; line2&quot;\n \n\nSynonyms:\nsorbet.format_key_value\nsorbet format_key_value","url":"sorbet.html#format_key_value"},{"doc":"sorbet","title":"parse","content":"pub fn parse(contents: String) -&gt; Dict(String, String)\n Parse a string in Sorbet format into a dictionary.\n\n The format follows these rules:\n - Each key-value pair is on a separate line with the format &quot;key =&gt; value&quot;\n - Multi-line values use continuation lines starting with &quot;&gt;&quot;\n - Empty lines are ignored\n - Whitespace around keys and values is trimmed\n\n ## Examples\n\n \n sorbet.parse(&quot;key =&gt; value&quot;)\n // Returns a dictionary with {&quot;key&quot;: &quot;value&quot;}\n\n sorbet.parse(&quot;key =&gt; first line\\n&gt; second line&quot;)\n // Returns a dictionary with {&quot;key&quot;: &quot;first line\\nsecond line&quot;}\n \n\nSynonyms:\nsorbet.parse\nsorbet parse","url":"sorbet.html#parse"},{"doc":"sorbet","title":"sorbet","content":" Sorbet\n This is the main module for Sorbet.\n It contains the types and functions for the Sorbet language.\n\n Sorbet is a simple key-value configuration format with support for\n multi-line values using continuation lines.\n\n Example:\n ```\n key1 =&gt; value1\n key2 =&gt; first line\n &gt; second line\n &gt; third line\n ```","url":"sorbet.html"}]);